@@ -54,6 +54,7 @@ SOFTWARE.
 #include "Xatomtype.h"
 #include <X11/Xatom.h>
 #include <X11/Xos.h>
+#include "reallocarray.h"
 
 #define safestrlen(s) ((s) ? strlen(s) : 0)
 
@@ -181,10 +182,8 @@ XSetIconSizes (
 {
 	register int i;
 	xPropIconSize *pp, *prop;
-#define size_of_the_real_thing sizeof	/* avoid grepping screwups */
-	unsigned nbytes = count * size_of_the_real_thing(xPropIconSize);
-#undef size_of_the_real_thing
-	if ((prop = pp = (xPropIconSize *) Xmalloc (nbytes))) {
+
+	if ((prop = pp = Xmallocarray (count, sizeof(xPropIconSize)))) {
 	    for (i = 0; i < count; i++) {
 		pp->minWidth  = list->min_width;
 		pp->minHeight = list->min_height;
@@ -198,7 +197,7 @@ XSetIconSizes (
 	    XChangeProperty (dpy, w, XA_WM_ICON_SIZE, XA_WM_ICON_SIZE, 32,
 			     PropModeReplace, (unsigned char *) prop,
 			     count * NumPropIconSizeElements);
-	    Xfree ((char *)prop);
+	    Xfree (prop);
 	}
 	return 1;
 }
@@ -211,12 +210,12 @@ XSetCommand (
 	int argc)
 {
 	register int i;
-	register int nbytes;
+	size_t nbytes;
 	register char *buf, *bp;
 	for (i = 0, nbytes = 0; i < argc; i++) {
 		nbytes += safestrlen(argv[i]) + 1;
 	}
-	if ((bp = buf = Xmalloc((unsigned) nbytes))) {
+	if ((bp = buf = Xmalloc(nbytes))) {
 	    /* copy arguments into single buffer */
 	    for (i = 0; i < argc; i++) {
 		if (argv[i]) {
@@ -295,11 +294,11 @@ XSetClassHint(
 {
 	char *class_string;
 	char *s;
-	int len_nm, len_cl;
+	size_t len_nm, len_cl;
 
 	len_nm = safestrlen(classhint->res_name);
 	len_cl = safestrlen(classhint->res_class);
-	if ((class_string = s = Xmalloc((unsigned) (len_nm + len_cl + 2)))) {
+	if ((class_string = s = Xmalloc(len_nm + len_cl + 2))) {
 	    if (len_nm) {
 		strcpy(s, classhint->res_name);
 		s += len_nm + 1;
