@@ -1,4 +1,3 @@
-/* $Xorg: lcCT.c,v 1.4 2000/08/17 19:45:16 cpqbld Exp $ */
 /*
  * Copyright 1992, 1993 by TOSHIBA Corp.
  *
@@ -36,7 +35,6 @@
  *  Modifier: Ivan Pascal     The XFree86 Project
  *  Modifier: Bruno Haible    The XFree86 Project
  */
-/* $XFree86: xc/lib/X11/lcCT.c,v 3.26 2001/10/28 03:32:34 tsi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -53,11 +51,11 @@
  * Static representation of a character set that can be used in Compound Text.
  */
 typedef struct _CTDataRec {
-    const char *name;
-    const char *ct_sequence;	/* Compound Text encoding, ESC sequence */
+    const char name[19];
+    const char ct_sequence[5];	/* Compound Text encoding, ESC sequence */
 } CTDataRec, *CTData;
 
-static CTDataRec default_ct_data[] =
+static const CTDataRec default_ct_data[] =
 {
     /*                                                                    */
     /* X11 registry name       MIME name         ISO-IR      ESC sequence */
@@ -125,6 +123,8 @@ static CTDataRec default_ct_data[] =
 #endif
     /* For use by utf8 -> ctext */
     { "BIG5-0:GLGR", "\033%/2"},
+    { "BIG5HKSCS-0:GLGR", "\033%/2"},
+    { "GBK-0:GLGR", "\033%/2"},
     /* used by Emacs, but not backed by ISO-IR */
     { "BIG5-E0:GL", "\033$(0" },
     { "BIG5-E0:GR", "\033$)0" },
@@ -319,7 +319,7 @@ _XlcParseCharSet(
     const char *ptr = charset->ct_sequence;
     int length;
     int char_size;
-    
+
     if (*ptr == '\0')
     	return False;
 
@@ -478,7 +478,7 @@ _XlcAddCT(
 
     /* Allocate a CTinfo record. */
     length = strlen(ct_sequence);
-    ct_info = (CTInfo) Xmalloc(sizeof(CTInfoRec) + length+1);
+    ct_info = Xmalloc(sizeof(CTInfoRec) + length+1);
     if (ct_info == NULL)
 	return charset;
 
@@ -514,7 +514,7 @@ _XlcAddCT(
                 Xfree(ct_info);
                 return charset;
             }
-            p = (char *) Xmalloc(n+1);
+            p = Xmalloc(n+1);
             if (p == NULL) {
                 Xfree(ct_info);
                 return charset;
@@ -751,7 +751,7 @@ cttocs(
                or stop the current run. */
             if (charset) {
                 if (charset != ch_charset)
-                    break; 
+                    break;
             } else {
                 state->charset = charset = ch_charset;
             }
@@ -791,7 +791,7 @@ cttocs(
                or stop the current run. */
             if (charset) {
                 if (charset != state->charset)
-                    break; 
+                    break;
             } else {
                 charset = state->charset;
             }
@@ -970,7 +970,7 @@ cstoct(
 		/* The CompoundText specification says that the only
 		   control characters allowed are 0x09, 0x0a, 0x1b, 0x9b.
 		   Therefore here we eliminate other control characters. */
-		unsigned char ch = *((unsigned char *) csptr) & 0x7f;
+		unsigned char ch = *((const unsigned char *) csptr) & 0x7f;
 		if (!((ch >= min_ch && ch <= max_ch)
 		      || (side == XlcGL
 			  && (ch == 0x00 || ch == 0x09 || ch == 0x0a))
@@ -1020,20 +1020,20 @@ cstoct(
 #endif
            ) {
             while (csstr_len > 0 && ct_len > 0) {
-                unsigned char ch = * (unsigned char *) csptr;
-                int char_size = (ch < 0xc0 ? 1 :
+                unsigned char ch = * (const unsigned char *) csptr;
+                int ch_size = (ch < 0xc0 ? 1 :
                                  ch < 0xe0 ? 2 :
                                  ch < 0xf0 ? 3 :
                                  ch < 0xf8 ? 4 :
                                  ch < 0xfc ? 5 :
                                              6);
                 int i;
-                if (!(csstr_len >= char_size && ct_len >= char_size))
+                if (!(csstr_len >= ch_size && ct_len >= ch_size))
                     break;
-                for (i = char_size; i > 0; i--)
+                for (i = ch_size; i > 0; i--)
                     *ctptr++ = *csptr++;
-                csstr_len -= char_size;
-                ct_len -= char_size;
+                csstr_len -= ch_size;
+                ct_len -= ch_size;
             }
         } else {
             while (csstr_len > 0 && ct_len > 0) {
@@ -1093,11 +1093,11 @@ strtocs(
     dst = (char *) *to;
 
     length = min(*from_left, *to_left);
-    side = *((unsigned char *) src) & 0x80;
+    side = *((const unsigned char *) src) & 0x80;
 
-    while (side == (*((unsigned char *) src) & 0x80) && length-- > 0)
+    while (side == (*((const unsigned char *) src) & 0x80) && length-- > 0)
 	*dst++ = *src++;
-    
+
     *from_left -= src - (const char *) *from;
     *from = (XPointer) src;
     *to_left -= dst - (char *) *to;
@@ -1133,14 +1133,14 @@ cstostr(
 	|| !((XlcCharSet) args[0] == state->GL_charset
 	     || (XlcCharSet) args[0] == state->GR_charset))
 	return -1;
-    
+
     csptr = *((const char **) from);
     string_ptr = *((char **) to);
     csstr_len = *from_left;
     str_len = *to_left;
 
     while (csstr_len > 0 && str_len > 0) {
-	ch = *((unsigned char *) csptr++);
+	ch = *((const unsigned char *) csptr++);
 	csstr_len--;
 	/* Citing ICCCM: "STRING as a type specifies the ISO Latin-1 character
 	   set plus the control characters TAB and NEWLINE." */
@@ -1169,7 +1169,7 @@ create_conv(
 {
     XlcConv conv;
 
-    conv = (XlcConv) Xmalloc(sizeof(XlcConvRec) + sizeof(StateRec));
+    conv = Xmalloc(sizeof(XlcConvRec) + sizeof(StateRec));
     if (conv == NULL)
 	return (XlcConv) NULL;
 
@@ -1187,7 +1187,7 @@ close_converter(
     XlcConv conv)
 {
     /* conv->state is allocated together with conv, free both at once.  */
-    Xfree((char *) conv);
+    Xfree(conv);
 }
 
 
@@ -1262,10 +1262,10 @@ open_cstostr(
 /* =========================== Initialization =========================== */
 
 Bool
-_XlcInitCTInfo()
+_XlcInitCTInfo(void)
 {
     if (ct_list == NULL) {
-        CTData ct_data;
+        const CTDataRec *ct_data;
         int num;
         XlcCharSet charset;
 
